@@ -5,7 +5,7 @@ from aiohttp.client_exceptions import ContentTypeError
 async def post(endpoint_uri, data, **kwargs):
     async with aiohttp.ClientSession() as session:
         async with session.post(endpoint_uri, json=data, **kwargs) as response:
-            # print("Raw response from server: ", response.status, await response.text())
+            print("Raw post response from server: ", response.status, await response.text())
             ctype = response.headers['Content-Type']
             expect = "text/plain"
             if expect in ctype:
