@@ -9,7 +9,6 @@ from rlp.sedes import (
 )
 from .keystore import sha3
 from .types import (
-    bytearray_to_bytestr,
     decode_hex,
     encode_hex,
     encode_number
@@ -157,22 +156,26 @@ def meter_tx_convert_to_eth_tx(tx):
         s = tx["ethTx"]["s"]
         v = tx["ethTx"]["v"]
 
-    return {
-        "hash": tx["id"],
-        "nonce": tx["nonce"],
-        "blockHash": tx["meta"]["blockID"],
-        "blockNumber": encode_number(tx["meta"]["blockNumber"]),
-        "transactionIndex": encode_number(0),
-        "from": tx["origin"],
-        "to": tx["clauses"][0]["to"],
-        "value": tx["clauses"][0]["value"],
-        "gas": encode_number(tx["gas"]),
-        "gasPrice": encode_number(1),
-        "input": tx["clauses"][0]["data"],
-        "r": r,
-        "s": s,
-        "v": v,
-    }
+    try:
+        res = {
+            "hash": tx["id"],
+            "nonce": tx["nonce"],
+            "blockHash": tx["meta"]["blockID"],
+            "blockNumber": encode_number(tx["meta"]["blockNumber"]),
+            "transactionIndex": encode_number(0),
+            "from": tx["origin"],
+            "to": tx["clauses"][0]["to"],
+            "value": tx["clauses"][0]["value"],
+            "gas": encode_number(tx["gas"]),
+            "gasPrice": encode_number(1),
+            "input": tx["clauses"][0]["data"],
+            "r": r,
+            "s": s,
+            "v": v,
+        }
+        return res
+    except Exception as e:
+        print("ERROR: ", e)
 
 
 #
@@ -256,7 +259,9 @@ TX_DATA_NON_ZERO_GAS = 68
 def data_gas(data):
     if data is None:
         return 0
-    data = decode_hex(data)
+    if data.startswith('0x'):
+        data = data[2:]
+    data = bytes.fromhex(data)
     if len(data) == 0:
         return 0
     z = 0
